is_running

Function is_running 

pub fn is_running(core: Cpu) -> bool
Available on crate feature unstable only.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.